[Bf-blender-cvs] [e49d66f22cf] master: Cleanup: typo in function name

Campbell Barton noreply at git.blender.org
Wed Mar 28 11:24:06 CEST 2018


Commit: e49d66f22cf7ac14e7254150387eb8e07114f20c
Author: Campbell Barton
Date:   Wed Mar 28 11:23:38 2018 +0200
Branches: master
https://developer.blender.org/rBe49d66f22cf7ac14e7254150387eb8e07114f20c

Cleanup: typo in function name

===================================================================

M	source/blender/blenlib/BLI_array_utils.h
M	source/blender/blenlib/intern/array_utils.c

===================================================================

diff --git a/source/blender/blenlib/BLI_array_utils.h b/source/blender/blenlib/BLI_array_utils.h
index 644faad636a..9a510bcfc3b 100644
--- a/source/blender/blenlib/BLI_array_utils.h
+++ b/source/blender/blenlib/BLI_array_utils.h
@@ -81,11 +81,11 @@ bool _bli_array_iter_span(
 	        arr, arr_len, sizeof(*(arr)), use_wrap, use_delimit_bounds, test_fn, user_data, \
 	        span_step, r_span_len)
 
-bool _bli_array_is_zerod(
+bool _bli_array_is_zeroed(
         const void *arr,
         unsigned int arr_len, size_t arr_stride);
-#define BLI_array_is_zerod(arr, arr_len) \
-	_bli_array_is_zerod( \
+#define BLI_array_is_zeroed(arr, arr_len) \
+	_bli_array_is_zeroed( \
 	        arr, arr_len, sizeof(*(arr)))
 
 #endif  /* __BLI_ARRAY_UTILS_H__ */
diff --git a/source/blender/blenlib/intern/array_utils.c b/source/blender/blenlib/intern/array_utils.c
index e407a92d6f6..7b2d35a763c 100644
--- a/source/blender/blenlib/intern/array_utils.c
+++ b/source/blender/blenlib/intern/array_utils.c
@@ -310,9 +310,9 @@ bool _bli_array_iter_span(
 }
 
 /**
  * Simple utility to check memory is zero'd.
  */
-bool _bli_array_is_zerod(
+bool _bli_array_is_zeroed(
         const void *arr_v,
         unsigned int arr_len, size_t arr_stride)
 {
@@ -310,9 +310,9 @@ bool _bli_array_iter_span(
 
 /**
- * Simple utility to check memory is zero'd.
+ * Simple utility to check memory is zeroed.
  */



More information about the Bf-blender-cvs mailing list